@@ -19,7 +19,7 @@ BRIDGE_HOTPLUG=no
 
 [ "$BRIDGE_HOTPLUG" = "no" ] && exit 0
 
-. /lib/bridge-utils/bridge-utils.sh
+. /usr/lib/bridge-utils/bridge-utils.sh
 
 if [ -d /run/network ]; then
    for i in $(ifquery --list --allow auto); do
